
# Welcome to your new Simmate project!

Make sure you have gone through our tutorials because making a custom project
can be difficult for those new to coding and Simmate.

Tutorials are at: https://jacksund.github.io/simmate/getting_started/overview/
